sconce.models.layers package — Pytorch-Sconce master documentation

# sconce.models.layers package

## sconce.models.layers.convolution2d_layer module

class `sconce.models.layers.convolution2d_layer.` `Convolution2dLayer`(*, in_channels, out_channels, stride=2, kernel_size=3, padding=1, inplace_activation=False, preactivate=False, with_batchnorm=True)

  Bases: `torch.nn.modules.module.Module`

  `forward`(x)
  `out_height`(in_height)
  `out_width`(in_width)

## sconce.models.layers.fully_connected_layer module

class `sconce.models.layers.fully_connected_layer.` `FullyConnectedLayer`(in_size, out_size, activation, with_batchnorm=True, dropout=0.0)

  Bases: `torch.nn.modules.module.Module`

  `forward`(x_in)